@@ -213,7 +213,7 @@ class AbstractInterface():
     settings_button = settings_dialog.action_area.get_children()[0]
     settings_button.connect('clicked', self.__show_settings_dialog)
 
-    settings_dialog.vbox.set_size_request(-1, height)
+    settings_dialog.vbox.set_size_request(-1, min(350, height))
     settings_dialog.show_all()
     self.__processing = False
 
