@@ -80,12 +80,12 @@ class WLANInterface(AbstractInterface):
       cmd = []
       if self.state['value'] == 2:
         try:
-          cmd.append("dbus-send --print-reply --system --dest=com.nokia.icd2 /com/nokia/icd2 com.nokia.icd2.disconnect_req uint32:0x8000")
-          #self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
+          #cmd.append("dbus-send --print-reply --system --dest=com.nokia.icd2 /com/nokia/icd2 com.nokia.icd2.disconnect_req uint32:0x8000")
+          self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
         except:
-          #self.reinit_interface('ICD')
+          self.reinit_interface('ICD')
           #self.get_interface('ICD').disconnect_req(dbus.UInt32(32768))
-          pass
+          #pass
       #run_async(self.run_commands, (self.wifi_turn_off_cmd,))
       cmd.extend(self.wifi_turn_off_cmd)
       gobject.idle_add(self.run_commands, cmd)
